@@ -14,12 +14,13 @@ if TYPE_CHECKING:
 
 def from_pandas_series(se: pd.Series) -> DataArray:
     row_index = se.axes[0]
-    row_index_name = row_index.name or "row"
+    row_index_name = "row" if row_index.name is None else str(row_index.name)
+    name = "" if se.name is None else str(se.name)
 
     return DataArray(
         data=Variable(values=se.values, dims=[row_index_name]),
         coords={row_index_name: Variable(dims=[row_index_name], values=row_index)},
-        name=se.name or "")
+        name=name)
 
 
 def from_pandas_dataframe(df: pd.DataFrame) -> Dataset:
