@@ -1,6 +1,7 @@
 # SPDX-License-Identifier: BSD-3-Clause
 # Copyright (c) 2022 Scipp contributors (https://github.com/scipp)
 # @author Simon Heybrock
+import itertools
 import warnings
 from numbers import Integral
 from typing import Dict, List, Optional, Union, Sequence
@@ -8,6 +9,7 @@ from typing import Dict, List, Optional, Union, Sequence
 from .._scipp import core as _cpp
 from .variable import array, Variable, linspace, arange, epoch, scalar
 from .math import round as round_
+from .bin_remapping import combine_bins
 
 
 def make_histogrammed(x: Union[_cpp.Variable, _cpp.DataArray, _cpp.Dataset], *,
@@ -99,16 +101,35 @@ def make_binned(x: Union[_cpp.Variable, _cpp.DataArray],
         groups = []
     if edges is None:
         edges = []
-    if isinstance(x, Variable):
+    if isinstance(x, Variable) and x.bins is not None:
+        x = _cpp.DataArray(x)
+    elif isinstance(x, Variable):
         coords = [*edges, *groups]
         if len(coords) != 1:
             raise ValueError("Edges for exactly one dimension must be specified when "
                              "binning or histogramming a variable.")
         data = scalar(1.0, unit='counts').broadcast(sizes=x.sizes).copy()
         x = _cpp.DataArray(data, coords={coords[0].dim: x})
+    if _can_operate_on_bins(x, edges, groups, erase):
+        return combine_bins(x, edges=edges, groups=groups, dim=erase)
     return _cpp.bin(x, edges, groups, erase)
 
 
+def _can_operate_on_bins(x, edges, groups, erase) -> bool:
+    if x.bins is None:
+        return False
+    dims = []
+    for coord in itertools.chain(edges, groups):
+        if coord.ndim != 1:
+            return False
+        if coord.dim in x.bins.meta:
+            return False
+        if coord.dim not in x.meta:
+            return False
+        dims += x.meta[coord.dim].dims
+    return set(dims) <= set(erase)
+
+
 def _require_coord(name, coord):
     if coord is None:
         raise _cpp.CoordError(f"Coordinate '{name}' not found.")
@@ -132,7 +153,7 @@ def _get_coord(x, name):
     return coord
 
 
-def _upper_bound(x):
+def _upper_bound(x: Variable) -> Variable:
     import numpy as np
     bound = x.max()
     if bound.dtype in ('int32', 'int64', 'datetime64'):
@@ -142,24 +163,25 @@ def _upper_bound(x):
     return bound
 
 
-def _parse_coords_arg(x, name, arg):
+def _parse_coords_arg(x: Union[_cpp.Variable, _cpp.DataArray, _cpp.Dataset], name: str,
+                      arg: Union[int, _cpp.Variable]) -> _cpp.Variable:
     if isinstance(arg, Variable) and name in arg.dims:
         return arg
     coord = _get_coord(x, name)
+    start = coord.min()
+    if not isinstance(x, Variable) and (name in x.meta) and x.meta.is_edges(name, name):
+        stop = coord.max()  # existing bin-edges, do not extend
+    else:
+        stop = _upper_bound(coord)
     if isinstance(arg, Integral):
-        start = coord.min()
         if start.dtype == _cpp.DType.datetime64:
             base = epoch(unit=start.unit)
-            return base + round_(
-                linspace(name, start - base, _upper_bound(coord) - base,
-                         num=arg + 1)).to(dtype='int64')
-        return linspace(name, start, _upper_bound(coord),
-                        num=arg + 1).to(dtype=start.dtype, copy=False)
-    start = coord.min()
+            return base + round_(linspace(name, start - base, stop - base,
+                                          num=arg + 1)).to(dtype='int64')
+        return linspace(name, start, stop, num=arg + 1).to(dtype=start.dtype,
+                                                           copy=False)
     step = arg.to(dtype=start.dtype, unit=start.unit)
-    stop = _upper_bound(coord) + step
-    # See #2639, need explicit dtype currently
-    return arange(name, start, stop, step=step, dtype=start.dtype)
+    return arange(name, start, stop + step, step=step)
 
 
 def _make_edges(x: Union[_cpp.Variable, _cpp.DataArray,
@@ -191,10 +213,10 @@ def hist(x: Union[_cpp.Variable, _cpp.DataArray, _cpp.Dataset],
 
     1. When an integer is provided, a 'linspace' with this requested number of
        bins is created, based on the min and max of the corresponding coordinate.
-    2. A scalar scipp variable (a value with a unit) is interpreted as a target
+    2. A scalar Scipp variable (a value with a unit) is interpreted as a target
        bin width, and an 'arange' covering the min and max of the corresponding
        coordinate is created.
-    3. A custom coordinate, given as a scipp variable with compatible unit.
+    3. A custom coordinate, given as a Scipp variable with compatible unit.
        Typically this should have a single dimension matching the target dimension.
 
     When histogramming a dimension with an existing dimension-coord, the binning for
@@ -339,10 +361,10 @@ def bin(x: Union[_cpp.Variable, _cpp.DataArray, _cpp.Dataset],
 
     1. When an integer is provided, a 'linspace' with this requested number of
        bins is created, based on the min and max of the corresponding coordinate.
-    2. A scalar scipp variable (a value with a unit) is interpreted as a target
+    2. A scalar Scipp variable (a value with a unit) is interpreted as a target
        bin width, and an 'arange' covering the min and max of the corresponding
        coordinate is created.
-    3. A custom coordinate, given as a scipp variable with compatible unit.
+    3. A custom coordinate, given as a Scipp variable with compatible unit.
        Typically, this should have a single dimension matching the target dimension.
 
     When binning a dimension with an existing dimension-coord, the binning for
@@ -539,7 +561,7 @@ def group(x: Union[_cpp.DataArray, _cpp.Dataset], /,
     """Create binned data by grouping input by one or more coordinates.
 
     Grouping can be specified in two ways: (1) When a string is provided the unique
-    values of the corresponding coordinate are used as groups. (2) When a scipp variable
+    values of the corresponding coordinate are used as groups. (2) When a Scipp variable
     is provided then the variable's values are used as groups.
 
     Note that option (1) may be very slow if the input is very large.
