@@ -7,8 +7,11 @@ from __future__ import annotations
 from pathlib import Path
 from typing import Union
 
+import numpy as np
+
 from ..logging import get_logger
 from ..typing import VariableLike
+from ..core.cpp_classes import Unit
 
 
 def _dtype_lut():
@@ -27,7 +30,6 @@ def _dtype_lut():
 
 
 def _as_hdf5_type(a):
-    import numpy as np
     if np.issubdtype(a.dtype, np.datetime64):
         return a.view(np.int64)
     return a
@@ -153,7 +155,7 @@ def _write_scipp_header(group, what):
 def _check_scipp_header(group, what):
     if 'scipp-version' not in group.attrs:
         raise RuntimeError(
-            "This does not look like an HDF5 file/group written by scipp.")
+            "This does not look like an HDF5 file/group written by Scipp.")
     if group.attrs['scipp-type'] != what:
         raise RuntimeError(
             f"Attempt to read {what}, found {group.attrs['scipp-type']}.")
@@ -176,6 +178,31 @@ def _data_handler_lut():
     return handler
 
 
+def _serialize_unit(unit):
+    unit_dict = unit.to_dict()
+    dtype = [('__version__', int), ('multiplier', float)]
+    vals = [unit_dict['__version__'], unit_dict['multiplier']]
+    if 'powers' in unit_dict:
+        dtype.append(('powers', [(name, int) for name in unit_dict['powers']]))
+        vals.append(tuple(val for val in unit_dict['powers'].values()))
+    return np.array(tuple(vals), dtype=dtype)
+
+
+def _read_unit_attr(ds):
+    u = ds.attrs['unit']
+    if isinstance(u, str):
+        return Unit(u)  # legacy encoding as a string
+
+    # u is a structured numpy array
+    unit_dict = {'__version__': u['__version__'], 'multiplier': u['multiplier']}
+    if 'powers' in u.dtype.names:
+        unit_dict['powers'] = {
+            name: u['powers'][name]
+            for name in u['powers'].dtype.names
+        }
+    return Unit.from_dict(unit_dict)
+
+
 class VariableIO:
     _dtypes = _dtype_lut()
     _data_handlers = _data_handler_lut()
@@ -202,7 +229,7 @@ class VariableIO:
         dset.attrs['shape'] = var.shape
         dset.attrs['dtype'] = str(var.dtype)
         if var.unit is not None:
-            dset.attrs['unit'] = str(var.unit)
+            dset.attrs['unit'] = _serialize_unit(var.unit)
         return group
 
     @classmethod
@@ -214,7 +241,7 @@ class VariableIO:
         contents = {key: values.attrs[key] for key in ['dims', 'shape']}
         contents['dtype'] = cls._dtypes[values.attrs['dtype']]
         if 'unit' in values.attrs:
-            contents['unit'] = sc.Unit(values.attrs['unit'])
+            contents['unit'] = _read_unit_attr(values)
         else:
             contents['unit'] = None  # essential, otherwise default unit is used
         contents['with_variances'] = 'variances' in group
