@@ -3,9 +3,10 @@
 # @author Neil Vaytet
 
 import ipywidgets as ipw
+from .displayable import Displayable
 
 
-class PlotPanel:
+class PlotPanel(Displayable):
     """
     Base class for providing additional widgets on top of the base dimension
     sliders and mask display control.
@@ -15,12 +16,6 @@ class PlotPanel:
         self.container = ipw.VBox()
         self.controller = None
 
-    def _ipython_display_(self):
-        """
-        IPython display representation for Jupyter notebooks.
-        """
-        return self._to_widget()._ipython_display_()
-
     def _to_widget(self):
         """
         Get the panel widgets in a single container box for display.
