@@ -5,6 +5,7 @@
 import ipywidgets as ipw
 
 from .. import config
+from .displayable import Displayable
 from .resampling_model import ResamplingMode
 
 
@@ -26,7 +27,7 @@ def _make_toggle_button(**kwargs):
     return button
 
 
-class PlotToolbar:
+class PlotToolbar(Displayable):
     """
     Custom toolbar with additional buttons for controlling log scales and
     normalization, and with back/forward buttons removed.
@@ -90,12 +91,6 @@ class PlotToolbar:
             self.members[f'toggle_{ax}axis_scale'] = self._log_axis[dim]
         self._update_container()
 
-    def _ipython_display_(self):
-        """
-        IPython display representation for Jupyter notebooks.
-        """
-        return self._to_widget()._ipython_display_()
-
     def _to_widget(self):
         """
         Return the VBox container
@@ -124,7 +119,7 @@ class PlotToolbar:
         """
         button = ipw.Button(**self._parse_button_args(**kwargs))
         set_button_color(button)
-        setattr(button, "value", value)
+        button.value = value
         self.toggle_button_color(owner=button, value=value)
         # Add a local observer to change the color of the button according to
         # its value.
@@ -152,7 +147,7 @@ class PlotToolbar:
                 if not isinstance(self.members[key], ipw.ToggleButton):
                     self.members[key].on_click(getattr(self, key))
         for dim, button in self._log_axis.items():
-            button.observe(getattr(controller, 'toggle_dim_scale')(dim), 'value')
+            button.observe(controller.toggle_dim_scale(dim), 'value')
         self._resampling_mode.observe(self.toggle_resampling_mode, 'value')
         if hasattr(controller, 'toggle_resampling_mode'):
             self._resampling_mode.observe(controller.toggle_resampling_mode, 'value')
