@@ -4,9 +4,10 @@
 from functools import partial
 from html import escape
 from ..utils import value_to_string
+from .displayable import Displayable
 
 
-class PlotWidgets:
+class PlotWidgets(Displayable):
     """
     Widgets containing a slider for each of the input's dimensions, as well as
     buttons to modify the currently displayed axes.
@@ -110,12 +111,6 @@ class PlotWidgets:
         self._add_masks_controls(masks)
         self.initialize(sizes=sizes)
 
-    def _ipython_display_(self):
-        """
-        IPython display representation for Jupyter notebooks.
-        """
-        return self._to_widget()._ipython_display_()
-
     def _to_widget(self):
         """
         Gather all widgets in a single container box.
@@ -141,8 +136,8 @@ class PlotWidgets:
                         description="{}:{}".format(escape(name), escape(key)),
                         indent=False,
                         layout={"width": "initial"})
-                    setattr(self.mask_checkboxes[name][key], "mask_group", name)
-                    setattr(self.mask_checkboxes[name][key], "mask_name", key)
+                    self.mask_checkboxes[name][key].mask_group = name
+                    self.mask_checkboxes[name][key].mask_name = key
 
         if masks_found:
             self.masks_lab = ipw.Label(value="Masks:")
@@ -334,20 +329,20 @@ class PlotWidgets:
         """
         Update the slider readout with new slider bounds.
         """
+
+        def format(val, d):
+            form = self._formatters[d]['linear']
+            if form is None:
+                return value_to_string(val)
+            # pos=None causes datetime formatter to return full string
+            # rather than attempting to set a separate label and returning
+            # offset
+            return form(val, pos=None)
+
         for dim in self._slider_dims:
-
-            def format(val):
-                form = self._formatters[dim]['linear']
-                if form is None:
-                    return value_to_string(val)
-                # pos=None causes datetime formatter to return full string
-                # rather than attempting to set a separate label and returning
-                # offset
-                return form(val, pos=None)
-
             if bounds[dim].values.ndim == 0:
-                bound = f'{format(bounds[dim].value)}'
+                bound = f'{format(bounds[dim].value, dim)}'
             else:
                 low, high = bounds[dim].values
-                bound = f'[{format(low)} {format(high)}]'
+                bound = f'[{format(low, dim)} {format(high, dim)}]'
             self._controls[dim]['value'].value = bound
