@@ -5,9 +5,9 @@
 def make_graphviz_digraph(*args, **kwargs):
     try:
         from graphviz import Digraph
-    except ImportError:
+    except ImportError as err:
         raise RuntimeError(
             "Failed to import `graphviz`. "
             "Use `pip install graphviz` (requires installed `graphviz` executable) or "
-            "`conda install -c conda-forge python-graphviz`.")
+            "`conda install -c conda-forge python-graphviz`.") from err
     return Digraph(*args, **kwargs)
